PROGRAM_NAME='Zigen_Main'
(***********************************************************)
(***********************************************************)
(*  FILE_LAST_MODIFIED_ON: 04/05/2006  AT: 09:00:25        *)
(***********************************************************)
(* System Type : NetLinx                                   *)
(***********************************************************)
(* REV HISTORY:                                            *)
(***********************************************************)
(*
    How to Use this module in your code:
    
    1. Add "Zigen_COMM.tko" file under modules in your work space.
    2. Only need to define in the main file is Zigen and virtual device.
    3. Add define Module section in your code.
    4. Send commands to module like the following example:
	
	SEND_COMMAND vdv_Zigen, '1x1'
	SEND_COMMAND vdv_Zigen, '16x16'
	
	1st number is input
	2nd number is output
	Need to add a 'x' in between input and output.
	
    5. Button events and variables in the "Zigen_Main" file are to trigger demo/test switching from a touchpanel.
*)
(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE

/*Touch Device*/
    Tp                  = 10001:07:0
    
/*Zigen Switcher*/
    Zigen               = 05001:01:0
/*Virtual Device*/ 
    vdv_Zigen           = 33060:01:0

(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

(***********************************************************)
(*              DATA TYPE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_TYPE

(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

/*Inputs*/
    INTEGER Input_Buttons[] = 
    {
	1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16
    }
    
/*Outputs*/
    INTEGER Output_Buttons[] = 
    {
	101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116
    }

/*Select input/output*/
    INTEGER Select_Input
    INTEGER Select_Output
    
/*Send Command to Zigen*/
    INTEGER Send_Selection_To_Device = 20

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE

(***********************************************************)
(*        SUBROUTINE/FUNCTION DEFINITIONS GO BELOW         *)
(***********************************************************)
(* EXAMPLE: DEFINE_FUNCTION <RETURN_TYPE> <NAME> (<PARAMETERS>) *)
(* EXAMPLE: DEFINE_CALL '<NAME>' (<PARAMETERS>) *)

(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START

/*Add under define start*/
    DEFINE_MODULE 'Zigen_COMM' mdlz1(Zigen,vdv_Zigen)

(***********************************************************)
(*                THE EVENTS GO BELOW                      *)
(***********************************************************)
DEFINE_EVENT

/*Input-Output Switching*/
BUTTON_EVENT[Tp,Input_Buttons] 
{
    PUSH:
	{
	Select_Input = Button.Input.Channel
	}
}
BUTTON_EVENT[Tp,Output_Buttons] 
{
    PUSH:
	{
	Select_Output = Button.Input.Channel - 100
	}
}
BUTTON_EVENT[Tp,Send_Selection_To_Device] 
{
    PUSH:
	{
	SEND_COMMAND vdv_Zigen, "itoa(Select_Input),'x',itoa(Select_Output)"
	/*examples for switch commands*/
	(*
	SEND_COMMAND vdv_Zigen, '1x1'
	SEND_COMMAND vdv_Zigen, '1x2'
	SEND_COMMAND vdv_Zigen, '1x16'
	SEND_COMMAND vdv_Zigen, '2x9'
	SEND_COMMAND vdv_Zigen, '5x4'
	SEND_COMMAND vdv_Zigen, '16x16'
	*)
	}
}

(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM

(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)

